@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Pod::Weaver::PluginBundle::RJBS;
 # ABSTRACT: RJBS's default Pod::Weaver config
-$Pod::Weaver::PluginBundle::RJBS::VERSION = '5.010';
+$Pod::Weaver::PluginBundle::RJBS::VERSION = '5.012';
 #pod =head1 OVERVIEW
 #pod
 #pod I<Roughly> equivalent to:
@@ -67,7 +67,7 @@ Pod::Weaver::PluginBundle::RJBS - RJBS's default Pod::Weaver config
 
 =head1 VERSION
 
-version 5.010
+version 5.012
 
 =head1 OVERVIEW
 
@@ -87,11 +87,11 @@ C<-Transformer> with L<Pod::Elemental::Transformer::List>
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2020 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
